/****************************************************************************
** Meta object code from reading C++ file 'sddmsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../sddmsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sddmsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12SddmSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto SddmSettings::qt_create_metaobjectdata<qt_meta_tag_ZN12SddmSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SddmSettings",
        "CurrentChanged",
        "",
        "MinimumUidChanged",
        "MaximumUidChanged",
        "UserChanged",
        "SessionChanged",
        "ReloginChanged",
        "HaltCommandChanged",
        "RebootCommandChanged",
        "current",
        "isCurrentImmutable",
        "defaultCurrentValue",
        "minimumUid",
        "isMinimumUidImmutable",
        "defaultMinimumUidValue",
        "maximumUid",
        "isMaximumUidImmutable",
        "defaultMaximumUidValue",
        "user",
        "isUserImmutable",
        "defaultUserValue",
        "session",
        "isSessionImmutable",
        "defaultSessionValue",
        "relogin",
        "isReloginImmutable",
        "defaultReloginValue",
        "haltCommand",
        "isHaltCommandImmutable",
        "defaultHaltCommandValue",
        "rebootCommand",
        "isRebootCommandImmutable",
        "defaultRebootCommandValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CurrentChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MinimumUidChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaximumUidChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UserChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SessionChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ReloginChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HaltCommandChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RebootCommandChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'current'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isCurrentImmutable'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCurrentValue'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'minimumUid'
        QtMocHelpers::PropertyData<uint>(13, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isMinimumUidImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMinimumUidValue'
        QtMocHelpers::PropertyData<uint>(15, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maximumUid'
        QtMocHelpers::PropertyData<uint>(16, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isMaximumUidImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaximumUidValue'
        QtMocHelpers::PropertyData<uint>(18, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'user'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isUserImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUserValue'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'session'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isSessionImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSessionValue'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'relogin'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isReloginImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultReloginValue'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'haltCommand'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isHaltCommandImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHaltCommandValue'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rebootCommand'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isRebootCommandImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRebootCommandValue'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SddmSettings, qt_meta_tag_ZN12SddmSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SddmSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<SddmSettingsBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SddmSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SddmSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12SddmSettingsE_t>.metaTypes,
    nullptr
} };

void SddmSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SddmSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CurrentChanged(); break;
        case 1: _t->MinimumUidChanged(); break;
        case 2: _t->MaximumUidChanged(); break;
        case 3: _t->UserChanged(); break;
        case 4: _t->SessionChanged(); break;
        case 5: _t->ReloginChanged(); break;
        case 6: _t->HaltCommandChanged(); break;
        case 7: _t->RebootCommandChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SddmSettings::*)()>(_a, &SddmSettings::CurrentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SddmSettings::*)()>(_a, &SddmSettings::MinimumUidChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SddmSettings::*)()>(_a, &SddmSettings::MaximumUidChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SddmSettings::*)()>(_a, &SddmSettings::UserChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SddmSettings::*)()>(_a, &SddmSettings::SessionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SddmSettings::*)()>(_a, &SddmSettings::ReloginChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SddmSettings::*)()>(_a, &SddmSettings::HaltCommandChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SddmSettings::*)()>(_a, &SddmSettings::RebootCommandChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->current(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isCurrentImmutable(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->defaultCurrentValue(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->minimumUid(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isMinimumUidImmutable(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->defaultMinimumUidValue(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->maximumUid(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isMaximumUidImmutable(); break;
        case 8: *reinterpret_cast<uint*>(_v) = _t->defaultMaximumUidValue(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->user(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isUserImmutable(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->defaultUserValue(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->session(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isSessionImmutable(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->defaultSessionValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->relogin(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isReloginImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultReloginValue(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->haltCommand(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isHaltCommandImmutable(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->defaultHaltCommandValue(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->rebootCommand(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isRebootCommandImmutable(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->defaultRebootCommandValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCurrent(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setMinimumUid(*reinterpret_cast<uint*>(_v)); break;
        case 6: _t->setMaximumUid(*reinterpret_cast<uint*>(_v)); break;
        case 9: _t->setUser(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setSession(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setRelogin(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setHaltCommand(*reinterpret_cast<QString*>(_v)); break;
        case 21: _t->setRebootCommand(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SddmSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SddmSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SddmSettingsE_t>.strings))
        return static_cast<void*>(this);
    return SddmSettingsBase::qt_metacast(_clname);
}

int SddmSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SddmSettingsBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void SddmSettings::CurrentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SddmSettings::MinimumUidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SddmSettings::MaximumUidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SddmSettings::UserChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SddmSettings::SessionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SddmSettings::ReloginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SddmSettings::HaltCommandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SddmSettings::RebootCommandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
